# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceInfo(object):
    """
    The Resource Info.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_compartment_id:
            The value to assign to the resource_compartment_id property of this ResourceInfo.
        :type resource_compartment_id: str

        :param resource_name:
            The value to assign to the resource_name property of this ResourceInfo.
        :type resource_name: str

        :param resource_id:
            The value to assign to the resource_id property of this ResourceInfo.
        :type resource_id: str

        :param resource_type:
            The value to assign to the resource_type property of this ResourceInfo.
        :type resource_type: str

        :param deployment_type:
            The value to assign to the deployment_type property of this ResourceInfo.
        :type deployment_type: str

        :param connector_id:
            The value to assign to the connector_id property of this ResourceInfo.
        :type connector_id: str

        :param is_cluster_db:
            The value to assign to the is_cluster_db property of this ResourceInfo.
        :type is_cluster_db: bool

        :param host_info:
            The value to assign to the host_info property of this ResourceInfo.
        :type host_info: list[oci.dblm.models.HostInfo]

        :param db_version:
            The value to assign to the db_version property of this ResourceInfo.
        :type db_version: str

        :param db_platform_type:
            The value to assign to the db_platform_type property of this ResourceInfo.
        :type db_platform_type: str

        :param license_type:
            The value to assign to the license_type property of this ResourceInfo.
        :type license_type: str

        :param agent_id:
            The value to assign to the agent_id property of this ResourceInfo.
        :type agent_id: str

        """
        self.swagger_types = {
            'resource_compartment_id': 'str',
            'resource_name': 'str',
            'resource_id': 'str',
            'resource_type': 'str',
            'deployment_type': 'str',
            'connector_id': 'str',
            'is_cluster_db': 'bool',
            'host_info': 'list[HostInfo]',
            'db_version': 'str',
            'db_platform_type': 'str',
            'license_type': 'str',
            'agent_id': 'str'
        }
        self.attribute_map = {
            'resource_compartment_id': 'resourceCompartmentId',
            'resource_name': 'resourceName',
            'resource_id': 'resourceId',
            'resource_type': 'resourceType',
            'deployment_type': 'deploymentType',
            'connector_id': 'connectorId',
            'is_cluster_db': 'isClusterDb',
            'host_info': 'hostInfo',
            'db_version': 'dbVersion',
            'db_platform_type': 'dbPlatformType',
            'license_type': 'licenseType',
            'agent_id': 'agentId'
        }
        self._resource_compartment_id = None
        self._resource_name = None
        self._resource_id = None
        self._resource_type = None
        self._deployment_type = None
        self._connector_id = None
        self._is_cluster_db = None
        self._host_info = None
        self._db_version = None
        self._db_platform_type = None
        self._license_type = None
        self._agent_id = None

    @property
    def resource_compartment_id(self):
        """
        **[Required]** Gets the resource_compartment_id of this ResourceInfo.
        The compartmentId of the resource.


        :return: The resource_compartment_id of this ResourceInfo.
        :rtype: str
        """
        return self._resource_compartment_id

    @resource_compartment_id.setter
    def resource_compartment_id(self, resource_compartment_id):
        """
        Sets the resource_compartment_id of this ResourceInfo.
        The compartmentId of the resource.


        :param resource_compartment_id: The resource_compartment_id of this ResourceInfo.
        :type: str
        """
        self._resource_compartment_id = resource_compartment_id

    @property
    def resource_name(self):
        """
        **[Required]** Gets the resource_name of this ResourceInfo.
        The name of the resource.


        :return: The resource_name of this ResourceInfo.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this ResourceInfo.
        The name of the resource.


        :param resource_name: The resource_name of this ResourceInfo.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def resource_id(self):
        """
        **[Required]** Gets the resource_id of this ResourceInfo.
        The Id of the resource.


        :return: The resource_id of this ResourceInfo.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this ResourceInfo.
        The Id of the resource.


        :param resource_id: The resource_id of this ResourceInfo.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """
        **[Required]** Gets the resource_type of this ResourceInfo.
        The type of the resource.


        :return: The resource_type of this ResourceInfo.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this ResourceInfo.
        The type of the resource.


        :param resource_type: The resource_type of this ResourceInfo.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def deployment_type(self):
        """
        **[Required]** Gets the deployment_type of this ResourceInfo.
        The deployment type of the resource.


        :return: The deployment_type of this ResourceInfo.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this ResourceInfo.
        The deployment type of the resource.


        :param deployment_type: The deployment_type of this ResourceInfo.
        :type: str
        """
        self._deployment_type = deployment_type

    @property
    def connector_id(self):
        """
        **[Required]** Gets the connector_id of this ResourceInfo.
        The connector Id of the resource.


        :return: The connector_id of this ResourceInfo.
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """
        Sets the connector_id of this ResourceInfo.
        The connector Id of the resource.


        :param connector_id: The connector_id of this ResourceInfo.
        :type: str
        """
        self._connector_id = connector_id

    @property
    def is_cluster_db(self):
        """
        Gets the is_cluster_db of this ResourceInfo.
        True if it is a cluster db.


        :return: The is_cluster_db of this ResourceInfo.
        :rtype: bool
        """
        return self._is_cluster_db

    @is_cluster_db.setter
    def is_cluster_db(self, is_cluster_db):
        """
        Sets the is_cluster_db of this ResourceInfo.
        True if it is a cluster db.


        :param is_cluster_db: The is_cluster_db of this ResourceInfo.
        :type: bool
        """
        self._is_cluster_db = is_cluster_db

    @property
    def host_info(self):
        """
        **[Required]** Gets the host_info of this ResourceInfo.
        host info objects


        :return: The host_info of this ResourceInfo.
        :rtype: list[oci.dblm.models.HostInfo]
        """
        return self._host_info

    @host_info.setter
    def host_info(self, host_info):
        """
        Sets the host_info of this ResourceInfo.
        host info objects


        :param host_info: The host_info of this ResourceInfo.
        :type: list[oci.dblm.models.HostInfo]
        """
        self._host_info = host_info

    @property
    def db_version(self):
        """
        **[Required]** Gets the db_version of this ResourceInfo.
        The version of the resource.


        :return: The db_version of this ResourceInfo.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this ResourceInfo.
        The version of the resource.


        :param db_version: The db_version of this ResourceInfo.
        :type: str
        """
        self._db_version = db_version

    @property
    def db_platform_type(self):
        """
        **[Required]** Gets the db_platform_type of this ResourceInfo.
        The platform type of the resource.


        :return: The db_platform_type of this ResourceInfo.
        :rtype: str
        """
        return self._db_platform_type

    @db_platform_type.setter
    def db_platform_type(self, db_platform_type):
        """
        Sets the db_platform_type of this ResourceInfo.
        The platform type of the resource.


        :param db_platform_type: The db_platform_type of this ResourceInfo.
        :type: str
        """
        self._db_platform_type = db_platform_type

    @property
    def license_type(self):
        """
        **[Required]** Gets the license_type of this ResourceInfo.
        The License Type of the resource.


        :return: The license_type of this ResourceInfo.
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """
        Sets the license_type of this ResourceInfo.
        The License Type of the resource.


        :param license_type: The license_type of this ResourceInfo.
        :type: str
        """
        self._license_type = license_type

    @property
    def agent_id(self):
        """
        Gets the agent_id of this ResourceInfo.
        The agent Id of the agent managing the resource.


        :return: The agent_id of this ResourceInfo.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this ResourceInfo.
        The agent Id of the agent managing the resource.


        :param agent_id: The agent_id of this ResourceInfo.
        :type: str
        """
        self._agent_id = agent_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AdditionalPatches(object):
    """
    Summary of patch recommendations for image.
    """

    #: A constant which can be used with the category property of a AdditionalPatches.
    #: This constant has a value of "RECOMMENDED"
    CATEGORY_RECOMMENDED = "RECOMMENDED"

    #: A constant which can be used with the category property of a AdditionalPatches.
    #: This constant has a value of "ADDITIONAL_PATCH"
    CATEGORY_ADDITIONAL_PATCH = "ADDITIONAL_PATCH"

    def __init__(self, **kwargs):
        """
        Initializes a new AdditionalPatches object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param patch_id:
            The value to assign to the patch_id property of this AdditionalPatches.
        :type patch_id: int

        :param patch_name:
            The value to assign to the patch_name property of this AdditionalPatches.
        :type patch_name: str

        :param description:
            The value to assign to the description property of this AdditionalPatches.
        :type description: str

        :param category:
            The value to assign to the category property of this AdditionalPatches.
            Allowed values for this property are: "RECOMMENDED", "ADDITIONAL_PATCH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        """
        self.swagger_types = {
            'patch_id': 'int',
            'patch_name': 'str',
            'description': 'str',
            'category': 'str'
        }
        self.attribute_map = {
            'patch_id': 'patchId',
            'patch_name': 'patchName',
            'description': 'description',
            'category': 'category'
        }
        self._patch_id = None
        self._patch_name = None
        self._description = None
        self._category = None

    @property
    def patch_id(self):
        """
        Gets the patch_id of this AdditionalPatches.
        Id for the patch recommendation.


        :return: The patch_id of this AdditionalPatches.
        :rtype: int
        """
        return self._patch_id

    @patch_id.setter
    def patch_id(self, patch_id):
        """
        Sets the patch_id of this AdditionalPatches.
        Id for the patch recommendation.


        :param patch_id: The patch_id of this AdditionalPatches.
        :type: int
        """
        self._patch_id = patch_id

    @property
    def patch_name(self):
        """
        Gets the patch_name of this AdditionalPatches.
        Name for the patch recommendation.


        :return: The patch_name of this AdditionalPatches.
        :rtype: str
        """
        return self._patch_name

    @patch_name.setter
    def patch_name(self, patch_name):
        """
        Sets the patch_name of this AdditionalPatches.
        Name for the patch recommendation.


        :param patch_name: The patch_name of this AdditionalPatches.
        :type: str
        """
        self._patch_name = patch_name

    @property
    def description(self):
        """
        Gets the description of this AdditionalPatches.
        Description of the patch recommendation.


        :return: The description of this AdditionalPatches.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AdditionalPatches.
        Description of the patch recommendation.


        :param description: The description of this AdditionalPatches.
        :type: str
        """
        self._description = description

    @property
    def category(self):
        """
        Gets the category of this AdditionalPatches.
        Shows if patch is recommended or is an additional patch from an existing database.

        Allowed values for this property are: "RECOMMENDED", "ADDITIONAL_PATCH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The category of this AdditionalPatches.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this AdditionalPatches.
        Shows if patch is recommended or is an additional patch from an existing database.


        :param category: The category of this AdditionalPatches.
        :type: str
        """
        allowed_values = ["RECOMMENDED", "ADDITIONAL_PATCH"]
        if not value_allowed_none_or_none_sentinel(category, allowed_values):
            category = 'UNKNOWN_ENUM_VALUE'
        self._category = category

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceSummary(object):
    """
    Summary of dblm registered and unregistered resources.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_resources_count:
            The value to assign to the total_resources_count property of this ResourceSummary.
        :type total_resources_count: int

        :param registered_resources_count:
            The value to assign to the registered_resources_count property of this ResourceSummary.
        :type registered_resources_count: int

        :param not_registered_resources_count:
            The value to assign to the not_registered_resources_count property of this ResourceSummary.
        :type not_registered_resources_count: int

        :param vulnerable_resources_count:
            The value to assign to the vulnerable_resources_count property of this ResourceSummary.
        :type vulnerable_resources_count: int

        :param clean_resources_count:
            The value to assign to the clean_resources_count property of this ResourceSummary.
        :type clean_resources_count: int

        :param error_resources_count:
            The value to assign to the error_resources_count property of this ResourceSummary.
        :type error_resources_count: int

        """
        self.swagger_types = {
            'total_resources_count': 'int',
            'registered_resources_count': 'int',
            'not_registered_resources_count': 'int',
            'vulnerable_resources_count': 'int',
            'clean_resources_count': 'int',
            'error_resources_count': 'int'
        }
        self.attribute_map = {
            'total_resources_count': 'totalResourcesCount',
            'registered_resources_count': 'registeredResourcesCount',
            'not_registered_resources_count': 'notRegisteredResourcesCount',
            'vulnerable_resources_count': 'vulnerableResourcesCount',
            'clean_resources_count': 'cleanResourcesCount',
            'error_resources_count': 'errorResourcesCount'
        }
        self._total_resources_count = None
        self._registered_resources_count = None
        self._not_registered_resources_count = None
        self._vulnerable_resources_count = None
        self._clean_resources_count = None
        self._error_resources_count = None

    @property
    def total_resources_count(self):
        """
        **[Required]** Gets the total_resources_count of this ResourceSummary.
        The total number of resources.


        :return: The total_resources_count of this ResourceSummary.
        :rtype: int
        """
        return self._total_resources_count

    @total_resources_count.setter
    def total_resources_count(self, total_resources_count):
        """
        Sets the total_resources_count of this ResourceSummary.
        The total number of resources.


        :param total_resources_count: The total_resources_count of this ResourceSummary.
        :type: int
        """
        self._total_resources_count = total_resources_count

    @property
    def registered_resources_count(self):
        """
        **[Required]** Gets the registered_resources_count of this ResourceSummary.
        The total number of registered resources.


        :return: The registered_resources_count of this ResourceSummary.
        :rtype: int
        """
        return self._registered_resources_count

    @registered_resources_count.setter
    def registered_resources_count(self, registered_resources_count):
        """
        Sets the registered_resources_count of this ResourceSummary.
        The total number of registered resources.


        :param registered_resources_count: The registered_resources_count of this ResourceSummary.
        :type: int
        """
        self._registered_resources_count = registered_resources_count

    @property
    def not_registered_resources_count(self):
        """
        **[Required]** Gets the not_registered_resources_count of this ResourceSummary.
        The total number of resources that are not registered.


        :return: The not_registered_resources_count of this ResourceSummary.
        :rtype: int
        """
        return self._not_registered_resources_count

    @not_registered_resources_count.setter
    def not_registered_resources_count(self, not_registered_resources_count):
        """
        Sets the not_registered_resources_count of this ResourceSummary.
        The total number of resources that are not registered.


        :param not_registered_resources_count: The not_registered_resources_count of this ResourceSummary.
        :type: int
        """
        self._not_registered_resources_count = not_registered_resources_count

    @property
    def vulnerable_resources_count(self):
        """
        **[Required]** Gets the vulnerable_resources_count of this ResourceSummary.
        Total number of resources that have 1 or more vulnerabilities.


        :return: The vulnerable_resources_count of this ResourceSummary.
        :rtype: int
        """
        return self._vulnerable_resources_count

    @vulnerable_resources_count.setter
    def vulnerable_resources_count(self, vulnerable_resources_count):
        """
        Sets the vulnerable_resources_count of this ResourceSummary.
        Total number of resources that have 1 or more vulnerabilities.


        :param vulnerable_resources_count: The vulnerable_resources_count of this ResourceSummary.
        :type: int
        """
        self._vulnerable_resources_count = vulnerable_resources_count

    @property
    def clean_resources_count(self):
        """
        **[Required]** Gets the clean_resources_count of this ResourceSummary.
        Total number of resources that have 0 vulnerabilities.


        :return: The clean_resources_count of this ResourceSummary.
        :rtype: int
        """
        return self._clean_resources_count

    @clean_resources_count.setter
    def clean_resources_count(self, clean_resources_count):
        """
        Sets the clean_resources_count of this ResourceSummary.
        Total number of resources that have 0 vulnerabilities.


        :param clean_resources_count: The clean_resources_count of this ResourceSummary.
        :type: int
        """
        self._clean_resources_count = clean_resources_count

    @property
    def error_resources_count(self):
        """
        **[Required]** Gets the error_resources_count of this ResourceSummary.
        Total number of resources that contain an error.


        :return: The error_resources_count of this ResourceSummary.
        :rtype: int
        """
        return self._error_resources_count

    @error_resources_count.setter
    def error_resources_count(self, error_resources_count):
        """
        Sets the error_resources_count of this ResourceSummary.
        Total number of resources that contain an error.


        :param error_resources_count: The error_resources_count of this ResourceSummary.
        :type: int
        """
        self._error_resources_count = error_resources_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabasesSummary(object):
    """
    Summary of a databases.
    """

    #: A constant which can be used with the database_type property of a DatabasesSummary.
    #: This constant has a value of "SI"
    DATABASE_TYPE_SI = "SI"

    #: A constant which can be used with the database_type property of a DatabasesSummary.
    #: This constant has a value of "RAC"
    DATABASE_TYPE_RAC = "RAC"

    #: A constant which can be used with the lifecycle_state property of a DatabasesSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DatabasesSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DatabasesSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DatabasesSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DatabasesSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DatabasesSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabasesSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_id:
            The value to assign to the database_id property of this DatabasesSummary.
        :type database_id: str

        :param database_name:
            The value to assign to the database_name property of this DatabasesSummary.
        :type database_name: str

        :param database_type:
            The value to assign to the database_type property of this DatabasesSummary.
            Allowed values for this property are: "SI", "RAC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_type: str

        :param release:
            The value to assign to the release property of this DatabasesSummary.
        :type release: str

        :param release_full_version:
            The value to assign to the release_full_version property of this DatabasesSummary.
        :type release_full_version: str

        :param oracle_home_path:
            The value to assign to the oracle_home_path property of this DatabasesSummary.
        :type oracle_home_path: str

        :param current_patch_watermark:
            The value to assign to the current_patch_watermark property of this DatabasesSummary.
        :type current_patch_watermark: str

        :param host_or_cluster:
            The value to assign to the host_or_cluster property of this DatabasesSummary.
        :type host_or_cluster: str

        :param image_details:
            The value to assign to the image_details property of this DatabasesSummary.
        :type image_details: oci.dblm.models.ImageDetails

        :param patch_compliance_details:
            The value to assign to the patch_compliance_details property of this DatabasesSummary.
        :type patch_compliance_details: oci.dblm.models.PatchComplianceDetails

        :param patch_activity_details:
            The value to assign to the patch_activity_details property of this DatabasesSummary.
        :type patch_activity_details: oci.dblm.models.PatchActivityDetails

        :param patch_user:
            The value to assign to the patch_user property of this DatabasesSummary.
        :type patch_user: str

        :param sudo_file_path:
            The value to assign to the sudo_file_path property of this DatabasesSummary.
        :type sudo_file_path: str

        :param additional_patches:
            The value to assign to the additional_patches property of this DatabasesSummary.
        :type additional_patches: list[oci.dblm.models.AdditionalPatches]

        :param vulnerabilities_summary:
            The value to assign to the vulnerabilities_summary property of this DatabasesSummary.
        :type vulnerabilities_summary: object

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DatabasesSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DatabasesSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DatabasesSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DatabasesSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'database_id': 'str',
            'database_name': 'str',
            'database_type': 'str',
            'release': 'str',
            'release_full_version': 'str',
            'oracle_home_path': 'str',
            'current_patch_watermark': 'str',
            'host_or_cluster': 'str',
            'image_details': 'ImageDetails',
            'patch_compliance_details': 'PatchComplianceDetails',
            'patch_activity_details': 'PatchActivityDetails',
            'patch_user': 'str',
            'sudo_file_path': 'str',
            'additional_patches': 'list[AdditionalPatches]',
            'vulnerabilities_summary': 'object',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'database_id': 'databaseId',
            'database_name': 'databaseName',
            'database_type': 'databaseType',
            'release': 'release',
            'release_full_version': 'releaseFullVersion',
            'oracle_home_path': 'oracleHomePath',
            'current_patch_watermark': 'currentPatchWatermark',
            'host_or_cluster': 'hostOrCluster',
            'image_details': 'imageDetails',
            'patch_compliance_details': 'patchComplianceDetails',
            'patch_activity_details': 'patchActivityDetails',
            'patch_user': 'patchUser',
            'sudo_file_path': 'sudoFilePath',
            'additional_patches': 'additionalPatches',
            'vulnerabilities_summary': 'vulnerabilitiesSummary',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._database_id = None
        self._database_name = None
        self._database_type = None
        self._release = None
        self._release_full_version = None
        self._oracle_home_path = None
        self._current_patch_watermark = None
        self._host_or_cluster = None
        self._image_details = None
        self._patch_compliance_details = None
        self._patch_activity_details = None
        self._patch_user = None
        self._sudo_file_path = None
        self._additional_patches = None
        self._vulnerabilities_summary = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def database_id(self):
        """
        **[Required]** Gets the database_id of this DatabasesSummary.
        Database ocid.


        :return: The database_id of this DatabasesSummary.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this DatabasesSummary.
        Database ocid.


        :param database_id: The database_id of this DatabasesSummary.
        :type: str
        """
        self._database_id = database_id

    @property
    def database_name(self):
        """
        Gets the database_name of this DatabasesSummary.
        Database name.


        :return: The database_name of this DatabasesSummary.
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """
        Sets the database_name of this DatabasesSummary.
        Database name.


        :param database_name: The database_name of this DatabasesSummary.
        :type: str
        """
        self._database_name = database_name

    @property
    def database_type(self):
        """
        Gets the database_type of this DatabasesSummary.
        Database type.

        Allowed values for this property are: "SI", "RAC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_type of this DatabasesSummary.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this DatabasesSummary.
        Database type.


        :param database_type: The database_type of this DatabasesSummary.
        :type: str
        """
        allowed_values = ["SI", "RAC"]
        if not value_allowed_none_or_none_sentinel(database_type, allowed_values):
            database_type = 'UNKNOWN_ENUM_VALUE'
        self._database_type = database_type

    @property
    def release(self):
        """
        Gets the release of this DatabasesSummary.
        Database release.


        :return: The release of this DatabasesSummary.
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """
        Sets the release of this DatabasesSummary.
        Database release.


        :param release: The release of this DatabasesSummary.
        :type: str
        """
        self._release = release

    @property
    def release_full_version(self):
        """
        Gets the release_full_version of this DatabasesSummary.
        Database release full version.


        :return: The release_full_version of this DatabasesSummary.
        :rtype: str
        """
        return self._release_full_version

    @release_full_version.setter
    def release_full_version(self, release_full_version):
        """
        Sets the release_full_version of this DatabasesSummary.
        Database release full version.


        :param release_full_version: The release_full_version of this DatabasesSummary.
        :type: str
        """
        self._release_full_version = release_full_version

    @property
    def oracle_home_path(self):
        """
        Gets the oracle_home_path of this DatabasesSummary.
        Path to the Oracle home.


        :return: The oracle_home_path of this DatabasesSummary.
        :rtype: str
        """
        return self._oracle_home_path

    @oracle_home_path.setter
    def oracle_home_path(self, oracle_home_path):
        """
        Sets the oracle_home_path of this DatabasesSummary.
        Path to the Oracle home.


        :param oracle_home_path: The oracle_home_path of this DatabasesSummary.
        :type: str
        """
        self._oracle_home_path = oracle_home_path

    @property
    def current_patch_watermark(self):
        """
        Gets the current_patch_watermark of this DatabasesSummary.
        This is the hashcode representing the list of patches applied.


        :return: The current_patch_watermark of this DatabasesSummary.
        :rtype: str
        """
        return self._current_patch_watermark

    @current_patch_watermark.setter
    def current_patch_watermark(self, current_patch_watermark):
        """
        Sets the current_patch_watermark of this DatabasesSummary.
        This is the hashcode representing the list of patches applied.


        :param current_patch_watermark: The current_patch_watermark of this DatabasesSummary.
        :type: str
        """
        self._current_patch_watermark = current_patch_watermark

    @property
    def host_or_cluster(self):
        """
        Gets the host_or_cluster of this DatabasesSummary.
        For SI, hosted on host and for RAC, host on cluster.


        :return: The host_or_cluster of this DatabasesSummary.
        :rtype: str
        """
        return self._host_or_cluster

    @host_or_cluster.setter
    def host_or_cluster(self, host_or_cluster):
        """
        Sets the host_or_cluster of this DatabasesSummary.
        For SI, hosted on host and for RAC, host on cluster.


        :param host_or_cluster: The host_or_cluster of this DatabasesSummary.
        :type: str
        """
        self._host_or_cluster = host_or_cluster

    @property
    def image_details(self):
        """
        **[Required]** Gets the image_details of this DatabasesSummary.

        :return: The image_details of this DatabasesSummary.
        :rtype: oci.dblm.models.ImageDetails
        """
        return self._image_details

    @image_details.setter
    def image_details(self, image_details):
        """
        Sets the image_details of this DatabasesSummary.

        :param image_details: The image_details of this DatabasesSummary.
        :type: oci.dblm.models.ImageDetails
        """
        self._image_details = image_details

    @property
    def patch_compliance_details(self):
        """
        **[Required]** Gets the patch_compliance_details of this DatabasesSummary.

        :return: The patch_compliance_details of this DatabasesSummary.
        :rtype: oci.dblm.models.PatchComplianceDetails
        """
        return self._patch_compliance_details

    @patch_compliance_details.setter
    def patch_compliance_details(self, patch_compliance_details):
        """
        Sets the patch_compliance_details of this DatabasesSummary.

        :param patch_compliance_details: The patch_compliance_details of this DatabasesSummary.
        :type: oci.dblm.models.PatchComplianceDetails
        """
        self._patch_compliance_details = patch_compliance_details

    @property
    def patch_activity_details(self):
        """
        **[Required]** Gets the patch_activity_details of this DatabasesSummary.

        :return: The patch_activity_details of this DatabasesSummary.
        :rtype: oci.dblm.models.PatchActivityDetails
        """
        return self._patch_activity_details

    @patch_activity_details.setter
    def patch_activity_details(self, patch_activity_details):
        """
        Sets the patch_activity_details of this DatabasesSummary.

        :param patch_activity_details: The patch_activity_details of this DatabasesSummary.
        :type: oci.dblm.models.PatchActivityDetails
        """
        self._patch_activity_details = patch_activity_details

    @property
    def patch_user(self):
        """
        Gets the patch_user of this DatabasesSummary.
        Intermediate user to be used for patching, created and maintained by customers. This user requires sudo access to switch as Oracle home owner and root user


        :return: The patch_user of this DatabasesSummary.
        :rtype: str
        """
        return self._patch_user

    @patch_user.setter
    def patch_user(self, patch_user):
        """
        Sets the patch_user of this DatabasesSummary.
        Intermediate user to be used for patching, created and maintained by customers. This user requires sudo access to switch as Oracle home owner and root user


        :param patch_user: The patch_user of this DatabasesSummary.
        :type: str
        """
        self._patch_user = patch_user

    @property
    def sudo_file_path(self):
        """
        Gets the sudo_file_path of this DatabasesSummary.
        Path to sudo binary (executable) file


        :return: The sudo_file_path of this DatabasesSummary.
        :rtype: str
        """
        return self._sudo_file_path

    @sudo_file_path.setter
    def sudo_file_path(self, sudo_file_path):
        """
        Sets the sudo_file_path of this DatabasesSummary.
        Path to sudo binary (executable) file


        :param sudo_file_path: The sudo_file_path of this DatabasesSummary.
        :type: str
        """
        self._sudo_file_path = sudo_file_path

    @property
    def additional_patches(self):
        """
        Gets the additional_patches of this DatabasesSummary.
        List of additional patches on database.


        :return: The additional_patches of this DatabasesSummary.
        :rtype: list[oci.dblm.models.AdditionalPatches]
        """
        return self._additional_patches

    @additional_patches.setter
    def additional_patches(self, additional_patches):
        """
        Sets the additional_patches of this DatabasesSummary.
        List of additional patches on database.


        :param additional_patches: The additional_patches of this DatabasesSummary.
        :type: list[oci.dblm.models.AdditionalPatches]
        """
        self._additional_patches = additional_patches

    @property
    def vulnerabilities_summary(self):
        """
        Gets the vulnerabilities_summary of this DatabasesSummary.
        Summary of vulnerabilities found in registered resources grouped by severity.


        :return: The vulnerabilities_summary of this DatabasesSummary.
        :rtype: object
        """
        return self._vulnerabilities_summary

    @vulnerabilities_summary.setter
    def vulnerabilities_summary(self, vulnerabilities_summary):
        """
        Sets the vulnerabilities_summary of this DatabasesSummary.
        Summary of vulnerabilities found in registered resources grouped by severity.


        :param vulnerabilities_summary: The vulnerabilities_summary of this DatabasesSummary.
        :type: object
        """
        self._vulnerabilities_summary = vulnerabilities_summary

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DatabasesSummary.
        The current state of the database.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DatabasesSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DatabasesSummary.
        The current state of the database.


        :param lifecycle_state: The lifecycle_state of this DatabasesSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this DatabasesSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DatabasesSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DatabasesSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DatabasesSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this DatabasesSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DatabasesSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DatabasesSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DatabasesSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DatabasesSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DatabasesSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DatabasesSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DatabasesSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilityResourceSummary(object):
    """
    The assessed Resources.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilityResourceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VulnerabilityResourceSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this VulnerabilityResourceSummary.
        :type name: str

        :param version:
            The value to assign to the version property of this VulnerabilityResourceSummary.
        :type version: str

        :param release:
            The value to assign to the release property of this VulnerabilityResourceSummary.
        :type release: str

        :param platform:
            The value to assign to the platform property of this VulnerabilityResourceSummary.
        :type platform: str

        :param time_config_collected:
            The value to assign to the time_config_collected property of this VulnerabilityResourceSummary.
        :type time_config_collected: datetime

        :param time_scan_ended:
            The value to assign to the time_scan_ended property of this VulnerabilityResourceSummary.
        :type time_scan_ended: datetime

        :param image_id:
            The value to assign to the image_id property of this VulnerabilityResourceSummary.
        :type image_id: str

        :param subscribed_image:
            The value to assign to the subscribed_image property of this VulnerabilityResourceSummary.
        :type subscribed_image: str

        :param metric_errors:
            The value to assign to the metric_errors property of this VulnerabilityResourceSummary.
        :type metric_errors: list[oci.dblm.models.MetricError]

        :param child_pdbs:
            The value to assign to the child_pdbs property of this VulnerabilityResourceSummary.
        :type child_pdbs: list[oci.dblm.models.ChildPdb]

        :param vulnerabilities_summary:
            The value to assign to the vulnerabilities_summary property of this VulnerabilityResourceSummary.
        :type vulnerabilities_summary: object

        :param patch_recommendations_summary:
            The value to assign to the patch_recommendations_summary property of this VulnerabilityResourceSummary.
        :type patch_recommendations_summary: object

        :param patch_recommendations_details:
            The value to assign to the patch_recommendations_details property of this VulnerabilityResourceSummary.
        :type patch_recommendations_details: list[oci.dblm.models.PatchRecommendationsDetailsSummary]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'str',
            'release': 'str',
            'platform': 'str',
            'time_config_collected': 'datetime',
            'time_scan_ended': 'datetime',
            'image_id': 'str',
            'subscribed_image': 'str',
            'metric_errors': 'list[MetricError]',
            'child_pdbs': 'list[ChildPdb]',
            'vulnerabilities_summary': 'object',
            'patch_recommendations_summary': 'object',
            'patch_recommendations_details': 'list[PatchRecommendationsDetailsSummary]'
        }
        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'release': 'release',
            'platform': 'platform',
            'time_config_collected': 'timeConfigCollected',
            'time_scan_ended': 'timeScanEnded',
            'image_id': 'imageId',
            'subscribed_image': 'subscribedImage',
            'metric_errors': 'metricErrors',
            'child_pdbs': 'childPdbs',
            'vulnerabilities_summary': 'vulnerabilitiesSummary',
            'patch_recommendations_summary': 'patchRecommendationsSummary',
            'patch_recommendations_details': 'patchRecommendationsDetails'
        }
        self._id = None
        self._name = None
        self._version = None
        self._release = None
        self._platform = None
        self._time_config_collected = None
        self._time_scan_ended = None
        self._image_id = None
        self._subscribed_image = None
        self._metric_errors = None
        self._child_pdbs = None
        self._vulnerabilities_summary = None
        self._patch_recommendations_summary = None
        self._patch_recommendations_details = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VulnerabilityResourceSummary.
        The resource ID for this resource.


        :return: The id of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VulnerabilityResourceSummary.
        The resource ID for this resource.


        :param id: The id of this VulnerabilityResourceSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this VulnerabilityResourceSummary.
        The name of the resource.


        :return: The name of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VulnerabilityResourceSummary.
        The name of the resource.


        :param name: The name of this VulnerabilityResourceSummary.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        **[Required]** Gets the version of this VulnerabilityResourceSummary.
        A string representing the version of the resource.


        :return: The version of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this VulnerabilityResourceSummary.
        A string representing the version of the resource.


        :param version: The version of this VulnerabilityResourceSummary.
        :type: str
        """
        self._version = version

    @property
    def release(self):
        """
        **[Required]** Gets the release of this VulnerabilityResourceSummary.
        A string representing the release of the resource.


        :return: The release of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """
        Sets the release of this VulnerabilityResourceSummary.
        A string representing the release of the resource.


        :param release: The release of this VulnerabilityResourceSummary.
        :type: str
        """
        self._release = release

    @property
    def platform(self):
        """
        **[Required]** Gets the platform of this VulnerabilityResourceSummary.
        A string representing the platform of the resource.


        :return: The platform of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """
        Sets the platform of this VulnerabilityResourceSummary.
        A string representing the platform of the resource.


        :param platform: The platform of this VulnerabilityResourceSummary.
        :type: str
        """
        self._platform = platform

    @property
    def time_config_collected(self):
        """
        **[Required]** Gets the time_config_collected of this VulnerabilityResourceSummary.
        Time when the latest configuration collection happened.


        :return: The time_config_collected of this VulnerabilityResourceSummary.
        :rtype: datetime
        """
        return self._time_config_collected

    @time_config_collected.setter
    def time_config_collected(self, time_config_collected):
        """
        Sets the time_config_collected of this VulnerabilityResourceSummary.
        Time when the latest configuration collection happened.


        :param time_config_collected: The time_config_collected of this VulnerabilityResourceSummary.
        :type: datetime
        """
        self._time_config_collected = time_config_collected

    @property
    def time_scan_ended(self):
        """
        **[Required]** Gets the time_scan_ended of this VulnerabilityResourceSummary.
        Time when the latest scan happened for the resource.


        :return: The time_scan_ended of this VulnerabilityResourceSummary.
        :rtype: datetime
        """
        return self._time_scan_ended

    @time_scan_ended.setter
    def time_scan_ended(self, time_scan_ended):
        """
        Sets the time_scan_ended of this VulnerabilityResourceSummary.
        Time when the latest scan happened for the resource.


        :param time_scan_ended: The time_scan_ended of this VulnerabilityResourceSummary.
        :type: datetime
        """
        self._time_scan_ended = time_scan_ended

    @property
    def image_id(self):
        """
        **[Required]** Gets the image_id of this VulnerabilityResourceSummary.
        Identifier for the resource is subscribed to.


        :return: The image_id of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this VulnerabilityResourceSummary.
        Identifier for the resource is subscribed to.


        :param image_id: The image_id of this VulnerabilityResourceSummary.
        :type: str
        """
        self._image_id = image_id

    @property
    def subscribed_image(self):
        """
        **[Required]** Gets the subscribed_image of this VulnerabilityResourceSummary.
        Image the resource is subscribed to.


        :return: The subscribed_image of this VulnerabilityResourceSummary.
        :rtype: str
        """
        return self._subscribed_image

    @subscribed_image.setter
    def subscribed_image(self, subscribed_image):
        """
        Sets the subscribed_image of this VulnerabilityResourceSummary.
        Image the resource is subscribed to.


        :param subscribed_image: The subscribed_image of this VulnerabilityResourceSummary.
        :type: str
        """
        self._subscribed_image = subscribed_image

    @property
    def metric_errors(self):
        """
        **[Required]** Gets the metric_errors of this VulnerabilityResourceSummary.
        Metric errors.


        :return: The metric_errors of this VulnerabilityResourceSummary.
        :rtype: list[oci.dblm.models.MetricError]
        """
        return self._metric_errors

    @metric_errors.setter
    def metric_errors(self, metric_errors):
        """
        Sets the metric_errors of this VulnerabilityResourceSummary.
        Metric errors.


        :param metric_errors: The metric_errors of this VulnerabilityResourceSummary.
        :type: list[oci.dblm.models.MetricError]
        """
        self._metric_errors = metric_errors

    @property
    def child_pdbs(self):
        """
        **[Required]** Gets the child_pdbs of this VulnerabilityResourceSummary.
        PDBs for a CDB.


        :return: The child_pdbs of this VulnerabilityResourceSummary.
        :rtype: list[oci.dblm.models.ChildPdb]
        """
        return self._child_pdbs

    @child_pdbs.setter
    def child_pdbs(self, child_pdbs):
        """
        Sets the child_pdbs of this VulnerabilityResourceSummary.
        PDBs for a CDB.


        :param child_pdbs: The child_pdbs of this VulnerabilityResourceSummary.
        :type: list[oci.dblm.models.ChildPdb]
        """
        self._child_pdbs = child_pdbs

    @property
    def vulnerabilities_summary(self):
        """
        **[Required]** Gets the vulnerabilities_summary of this VulnerabilityResourceSummary.
        Summary of the resources that are registered and may or may not have vulnerabilities.


        :return: The vulnerabilities_summary of this VulnerabilityResourceSummary.
        :rtype: object
        """
        return self._vulnerabilities_summary

    @vulnerabilities_summary.setter
    def vulnerabilities_summary(self, vulnerabilities_summary):
        """
        Sets the vulnerabilities_summary of this VulnerabilityResourceSummary.
        Summary of the resources that are registered and may or may not have vulnerabilities.


        :param vulnerabilities_summary: The vulnerabilities_summary of this VulnerabilityResourceSummary.
        :type: object
        """
        self._vulnerabilities_summary = vulnerabilities_summary

    @property
    def patch_recommendations_summary(self):
        """
        **[Required]** Gets the patch_recommendations_summary of this VulnerabilityResourceSummary.
        Summary of the patch recommendations for databases.


        :return: The patch_recommendations_summary of this VulnerabilityResourceSummary.
        :rtype: object
        """
        return self._patch_recommendations_summary

    @patch_recommendations_summary.setter
    def patch_recommendations_summary(self, patch_recommendations_summary):
        """
        Sets the patch_recommendations_summary of this VulnerabilityResourceSummary.
        Summary of the patch recommendations for databases.


        :param patch_recommendations_summary: The patch_recommendations_summary of this VulnerabilityResourceSummary.
        :type: object
        """
        self._patch_recommendations_summary = patch_recommendations_summary

    @property
    def patch_recommendations_details(self):
        """
        **[Required]** Gets the patch_recommendations_details of this VulnerabilityResourceSummary.
        List of the patch recommendations for databases


        :return: The patch_recommendations_details of this VulnerabilityResourceSummary.
        :rtype: list[oci.dblm.models.PatchRecommendationsDetailsSummary]
        """
        return self._patch_recommendations_details

    @patch_recommendations_details.setter
    def patch_recommendations_details(self, patch_recommendations_details):
        """
        Sets the patch_recommendations_details of this VulnerabilityResourceSummary.
        List of the patch recommendations for databases


        :param patch_recommendations_details: The patch_recommendations_details of this VulnerabilityResourceSummary.
        :type: list[oci.dblm.models.PatchRecommendationsDetailsSummary]
        """
        self._patch_recommendations_details = patch_recommendations_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilitiesSummary(object):
    """
    Summary of vulnerabilities found in registered resources grouped by severity.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilitiesSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total:
            The value to assign to the total property of this VulnerabilitiesSummary.
        :type total: int

        :param critical:
            The value to assign to the critical property of this VulnerabilitiesSummary.
        :type critical: int

        :param high:
            The value to assign to the high property of this VulnerabilitiesSummary.
        :type high: int

        :param medium:
            The value to assign to the medium property of this VulnerabilitiesSummary.
        :type medium: int

        :param info:
            The value to assign to the info property of this VulnerabilitiesSummary.
        :type info: int

        :param low:
            The value to assign to the low property of this VulnerabilitiesSummary.
        :type low: int

        """
        self.swagger_types = {
            'total': 'int',
            'critical': 'int',
            'high': 'int',
            'medium': 'int',
            'info': 'int',
            'low': 'int'
        }
        self.attribute_map = {
            'total': 'total',
            'critical': 'critical',
            'high': 'high',
            'medium': 'medium',
            'info': 'info',
            'low': 'low'
        }
        self._total = None
        self._critical = None
        self._high = None
        self._medium = None
        self._info = None
        self._low = None

    @property
    def total(self):
        """
        **[Required]** Gets the total of this VulnerabilitiesSummary.
        Total number of vulnerabilities.


        :return: The total of this VulnerabilitiesSummary.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this VulnerabilitiesSummary.
        Total number of vulnerabilities.


        :param total: The total of this VulnerabilitiesSummary.
        :type: int
        """
        self._total = total

    @property
    def critical(self):
        """
        **[Required]** Gets the critical of this VulnerabilitiesSummary.
        Cumulative number of resources that have critical level vulnerabilities.


        :return: The critical of this VulnerabilitiesSummary.
        :rtype: int
        """
        return self._critical

    @critical.setter
    def critical(self, critical):
        """
        Sets the critical of this VulnerabilitiesSummary.
        Cumulative number of resources that have critical level vulnerabilities.


        :param critical: The critical of this VulnerabilitiesSummary.
        :type: int
        """
        self._critical = critical

    @property
    def high(self):
        """
        **[Required]** Gets the high of this VulnerabilitiesSummary.
        Cumulative number of resources that have high level vulnerabilities.


        :return: The high of this VulnerabilitiesSummary.
        :rtype: int
        """
        return self._high

    @high.setter
    def high(self, high):
        """
        Sets the high of this VulnerabilitiesSummary.
        Cumulative number of resources that have high level vulnerabilities.


        :param high: The high of this VulnerabilitiesSummary.
        :type: int
        """
        self._high = high

    @property
    def medium(self):
        """
        **[Required]** Gets the medium of this VulnerabilitiesSummary.
        Cumulative number of resources that have medium level vulnerabilities.


        :return: The medium of this VulnerabilitiesSummary.
        :rtype: int
        """
        return self._medium

    @medium.setter
    def medium(self, medium):
        """
        Sets the medium of this VulnerabilitiesSummary.
        Cumulative number of resources that have medium level vulnerabilities.


        :param medium: The medium of this VulnerabilitiesSummary.
        :type: int
        """
        self._medium = medium

    @property
    def info(self):
        """
        **[Required]** Gets the info of this VulnerabilitiesSummary.
        Cumulative number of resources that have info level vulnerabilities.


        :return: The info of this VulnerabilitiesSummary.
        :rtype: int
        """
        return self._info

    @info.setter
    def info(self, info):
        """
        Sets the info of this VulnerabilitiesSummary.
        Cumulative number of resources that have info level vulnerabilities.


        :param info: The info of this VulnerabilitiesSummary.
        :type: int
        """
        self._info = info

    @property
    def low(self):
        """
        **[Required]** Gets the low of this VulnerabilitiesSummary.
        Cumulative number of resources that have low level vulnerabilities.


        :return: The low of this VulnerabilitiesSummary.
        :rtype: int
        """
        return self._low

    @low.setter
    def low(self, low):
        """
        Sets the low of this VulnerabilitiesSummary.
        Cumulative number of resources that have low level vulnerabilities.


        :param low: The low of this VulnerabilitiesSummary.
        :type: int
        """
        self._low = low

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchRecommendationsDetailsSummary(object):
    """
    Summary of patch recommendations for databases.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PatchRecommendationsDetailsSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param patch_name:
            The value to assign to the patch_name property of this PatchRecommendationsDetailsSummary.
        :type patch_name: str

        :param abstract_text:
            The value to assign to the abstract_text property of this PatchRecommendationsDetailsSummary.
        :type abstract_text: str

        :param classification_name:
            The value to assign to the classification_name property of this PatchRecommendationsDetailsSummary.
        :type classification_name: str

        :param time_evaluated:
            The value to assign to the time_evaluated property of this PatchRecommendationsDetailsSummary.
        :type time_evaluated: datetime

        :param has_fix_for_cve:
            The value to assign to the has_fix_for_cve property of this PatchRecommendationsDetailsSummary.
        :type has_fix_for_cve: bool

        :param time_released:
            The value to assign to the time_released property of this PatchRecommendationsDetailsSummary.
        :type time_released: datetime

        """
        self.swagger_types = {
            'patch_name': 'str',
            'abstract_text': 'str',
            'classification_name': 'str',
            'time_evaluated': 'datetime',
            'has_fix_for_cve': 'bool',
            'time_released': 'datetime'
        }
        self.attribute_map = {
            'patch_name': 'patchName',
            'abstract_text': 'abstractText',
            'classification_name': 'classificationName',
            'time_evaluated': 'timeEvaluated',
            'has_fix_for_cve': 'hasFixForCve',
            'time_released': 'timeReleased'
        }
        self._patch_name = None
        self._abstract_text = None
        self._classification_name = None
        self._time_evaluated = None
        self._has_fix_for_cve = None
        self._time_released = None

    @property
    def patch_name(self):
        """
        **[Required]** Gets the patch_name of this PatchRecommendationsDetailsSummary.
        Name of the patch recommendation.


        :return: The patch_name of this PatchRecommendationsDetailsSummary.
        :rtype: str
        """
        return self._patch_name

    @patch_name.setter
    def patch_name(self, patch_name):
        """
        Sets the patch_name of this PatchRecommendationsDetailsSummary.
        Name of the patch recommendation.


        :param patch_name: The patch_name of this PatchRecommendationsDetailsSummary.
        :type: str
        """
        self._patch_name = patch_name

    @property
    def abstract_text(self):
        """
        **[Required]** Gets the abstract_text of this PatchRecommendationsDetailsSummary.
        Description of the patch recommendation.


        :return: The abstract_text of this PatchRecommendationsDetailsSummary.
        :rtype: str
        """
        return self._abstract_text

    @abstract_text.setter
    def abstract_text(self, abstract_text):
        """
        Sets the abstract_text of this PatchRecommendationsDetailsSummary.
        Description of the patch recommendation.


        :param abstract_text: The abstract_text of this PatchRecommendationsDetailsSummary.
        :type: str
        """
        self._abstract_text = abstract_text

    @property
    def classification_name(self):
        """
        **[Required]** Gets the classification_name of this PatchRecommendationsDetailsSummary.
        Classification of the patch recommendation.


        :return: The classification_name of this PatchRecommendationsDetailsSummary.
        :rtype: str
        """
        return self._classification_name

    @classification_name.setter
    def classification_name(self, classification_name):
        """
        Sets the classification_name of this PatchRecommendationsDetailsSummary.
        Classification of the patch recommendation.


        :param classification_name: The classification_name of this PatchRecommendationsDetailsSummary.
        :type: str
        """
        self._classification_name = classification_name

    @property
    def time_evaluated(self):
        """
        **[Required]** Gets the time_evaluated of this PatchRecommendationsDetailsSummary.
        Evaluation date for the patch recommendation.


        :return: The time_evaluated of this PatchRecommendationsDetailsSummary.
        :rtype: datetime
        """
        return self._time_evaluated

    @time_evaluated.setter
    def time_evaluated(self, time_evaluated):
        """
        Sets the time_evaluated of this PatchRecommendationsDetailsSummary.
        Evaluation date for the patch recommendation.


        :param time_evaluated: The time_evaluated of this PatchRecommendationsDetailsSummary.
        :type: datetime
        """
        self._time_evaluated = time_evaluated

    @property
    def has_fix_for_cve(self):
        """
        **[Required]** Gets the has_fix_for_cve of this PatchRecommendationsDetailsSummary.
        If the patch has a fix for a CVE.


        :return: The has_fix_for_cve of this PatchRecommendationsDetailsSummary.
        :rtype: bool
        """
        return self._has_fix_for_cve

    @has_fix_for_cve.setter
    def has_fix_for_cve(self, has_fix_for_cve):
        """
        Sets the has_fix_for_cve of this PatchRecommendationsDetailsSummary.
        If the patch has a fix for a CVE.


        :param has_fix_for_cve: The has_fix_for_cve of this PatchRecommendationsDetailsSummary.
        :type: bool
        """
        self._has_fix_for_cve = has_fix_for_cve

    @property
    def time_released(self):
        """
        **[Required]** Gets the time_released of this PatchRecommendationsDetailsSummary.
        Release date for the patch.


        :return: The time_released of this PatchRecommendationsDetailsSummary.
        :rtype: datetime
        """
        return self._time_released

    @time_released.setter
    def time_released(self, time_released):
        """
        Sets the time_released of this PatchRecommendationsDetailsSummary.
        Release date for the patch.


        :param time_released: The time_released of this PatchRecommendationsDetailsSummary.
        :type: datetime
        """
        self._time_released = time_released

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchRecommendationSummary(object):
    """
    Total count summary of patch recommendations for databases.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PatchRecommendationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total:
            The value to assign to the total property of this PatchRecommendationSummary.
        :type total: int

        :param up_to_date:
            The value to assign to the up_to_date property of this PatchRecommendationSummary.
        :type up_to_date: int

        :param patch_available:
            The value to assign to the patch_available property of this PatchRecommendationSummary.
        :type patch_available: int

        """
        self.swagger_types = {
            'total': 'int',
            'up_to_date': 'int',
            'patch_available': 'int'
        }
        self.attribute_map = {
            'total': 'total',
            'up_to_date': 'upToDate',
            'patch_available': 'patchAvailable'
        }
        self._total = None
        self._up_to_date = None
        self._patch_available = None

    @property
    def total(self):
        """
        **[Required]** Gets the total of this PatchRecommendationSummary.
        Total number of databases pending to be updated and/or with latest patches.


        :return: The total of this PatchRecommendationSummary.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this PatchRecommendationSummary.
        Total number of databases pending to be updated and/or with latest patches.


        :param total: The total of this PatchRecommendationSummary.
        :type: int
        """
        self._total = total

    @property
    def up_to_date(self):
        """
        **[Required]** Gets the up_to_date of this PatchRecommendationSummary.
        Number of databases with latest patches.


        :return: The up_to_date of this PatchRecommendationSummary.
        :rtype: int
        """
        return self._up_to_date

    @up_to_date.setter
    def up_to_date(self, up_to_date):
        """
        Sets the up_to_date of this PatchRecommendationSummary.
        Number of databases with latest patches.


        :param up_to_date: The up_to_date of this PatchRecommendationSummary.
        :type: int
        """
        self._up_to_date = up_to_date

    @property
    def patch_available(self):
        """
        **[Required]** Gets the patch_available of this PatchRecommendationSummary.
        Number of databases pending to be updated.


        :return: The patch_available of this PatchRecommendationSummary.
        :rtype: int
        """
        return self._patch_available

    @patch_available.setter
    def patch_available(self, patch_available):
        """
        Sets the patch_available of this PatchRecommendationSummary.
        Number of databases pending to be updated.


        :param patch_available: The patch_available of this PatchRecommendationSummary.
        :type: int
        """
        self._patch_available = patch_available

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102

from __future__ import absolute_import

from .additional_patches import AdditionalPatches
from .aggregated_vulnerability_collection import AggregatedVulnerabilityCollection
from .aggregated_vulnerability_summary import AggregatedVulnerabilitySummary
from .child_pdb import ChildPdb
from .create_vulnerability_scan_details import CreateVulnerabilityScanDetails
from .databases_summary import DatabasesSummary
from .dblm_patch_management import DblmPatchManagement
from .dblm_vulnerability import DblmVulnerability
from .fpp_server import FppServer
from .host_info import HostInfo
from .image_details import ImageDetails
from .images_patch_recommendation_summary import ImagesPatchRecommendationSummary
from .metric_error import MetricError
from .notification_collection import NotificationCollection
from .notification_summary import NotificationSummary
from .patch_activity_details import PatchActivityDetails
from .patch_compliance_details import PatchComplianceDetails
from .patch_databases_collection import PatchDatabasesCollection
from .patch_operations_summary import PatchOperationsSummary
from .patch_recommendation_summary import PatchRecommendationSummary
from .patch_recommendations_details_summary import PatchRecommendationsDetailsSummary
from .resource_info import ResourceInfo
from .resource_summary import ResourceSummary
from .resources_patch_compliance_summary import ResourcesPatchComplianceSummary
from .vulnerabilities_summary import VulnerabilitiesSummary
from .vulnerability_collection import VulnerabilityCollection
from .vulnerability_resource_collection import VulnerabilityResourceCollection
from .vulnerability_resource_summary import VulnerabilityResourceSummary
from .vulnerability_scan import VulnerabilityScan
from .vulnerability_scan_collection import VulnerabilityScanCollection
from .vulnerability_scan_summary import VulnerabilityScanSummary
from .vulnerability_summary import VulnerabilitySummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for dblm services.
dblm_type_mapping = {
    "AdditionalPatches": AdditionalPatches,
    "AggregatedVulnerabilityCollection": AggregatedVulnerabilityCollection,
    "AggregatedVulnerabilitySummary": AggregatedVulnerabilitySummary,
    "ChildPdb": ChildPdb,
    "CreateVulnerabilityScanDetails": CreateVulnerabilityScanDetails,
    "DatabasesSummary": DatabasesSummary,
    "DblmPatchManagement": DblmPatchManagement,
    "DblmVulnerability": DblmVulnerability,
    "FppServer": FppServer,
    "HostInfo": HostInfo,
    "ImageDetails": ImageDetails,
    "ImagesPatchRecommendationSummary": ImagesPatchRecommendationSummary,
    "MetricError": MetricError,
    "NotificationCollection": NotificationCollection,
    "NotificationSummary": NotificationSummary,
    "PatchActivityDetails": PatchActivityDetails,
    "PatchComplianceDetails": PatchComplianceDetails,
    "PatchDatabasesCollection": PatchDatabasesCollection,
    "PatchOperationsSummary": PatchOperationsSummary,
    "PatchRecommendationSummary": PatchRecommendationSummary,
    "PatchRecommendationsDetailsSummary": PatchRecommendationsDetailsSummary,
    "ResourceInfo": ResourceInfo,
    "ResourceSummary": ResourceSummary,
    "ResourcesPatchComplianceSummary": ResourcesPatchComplianceSummary,
    "VulnerabilitiesSummary": VulnerabilitiesSummary,
    "VulnerabilityCollection": VulnerabilityCollection,
    "VulnerabilityResourceCollection": VulnerabilityResourceCollection,
    "VulnerabilityResourceSummary": VulnerabilityResourceSummary,
    "VulnerabilityScan": VulnerabilityScan,
    "VulnerabilityScanCollection": VulnerabilityScanCollection,
    "VulnerabilityScanSummary": VulnerabilityScanSummary,
    "VulnerabilitySummary": VulnerabilitySummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NotificationSummary(object):
    """
    Notifications
    """

    #: A constant which can be used with the notification_type property of a NotificationSummary.
    #: This constant has a value of "CVE"
    NOTIFICATION_TYPE_CVE = "CVE"

    #: A constant which can be used with the notification_type property of a NotificationSummary.
    #: This constant has a value of "ADVISORY"
    NOTIFICATION_TYPE_ADVISORY = "ADVISORY"

    #: A constant which can be used with the notification_type property of a NotificationSummary.
    #: This constant has a value of "PATCH"
    NOTIFICATION_TYPE_PATCH = "PATCH"

    def __init__(self, **kwargs):
        """
        Initializes a new NotificationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param notification_type:
            The value to assign to the notification_type property of this NotificationSummary.
            Allowed values for this property are: "CVE", "ADVISORY", "PATCH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type notification_type: str

        :param notification_text:
            The value to assign to the notification_text property of this NotificationSummary.
        :type notification_text: str

        :param id:
            The value to assign to the id property of this NotificationSummary.
        :type id: str

        :param time_published:
            The value to assign to the time_published property of this NotificationSummary.
        :type time_published: datetime

        """
        self.swagger_types = {
            'notification_type': 'str',
            'notification_text': 'str',
            'id': 'str',
            'time_published': 'datetime'
        }
        self.attribute_map = {
            'notification_type': 'notificationType',
            'notification_text': 'notificationText',
            'id': 'id',
            'time_published': 'timePublished'
        }
        self._notification_type = None
        self._notification_text = None
        self._id = None
        self._time_published = None

    @property
    def notification_type(self):
        """
        **[Required]** Gets the notification_type of this NotificationSummary.
        Notification type

        Allowed values for this property are: "CVE", "ADVISORY", "PATCH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The notification_type of this NotificationSummary.
        :rtype: str
        """
        return self._notification_type

    @notification_type.setter
    def notification_type(self, notification_type):
        """
        Sets the notification_type of this NotificationSummary.
        Notification type


        :param notification_type: The notification_type of this NotificationSummary.
        :type: str
        """
        allowed_values = ["CVE", "ADVISORY", "PATCH"]
        if not value_allowed_none_or_none_sentinel(notification_type, allowed_values):
            notification_type = 'UNKNOWN_ENUM_VALUE'
        self._notification_type = notification_type

    @property
    def notification_text(self):
        """
        **[Required]** Gets the notification_text of this NotificationSummary.
        Notification text


        :return: The notification_text of this NotificationSummary.
        :rtype: str
        """
        return self._notification_text

    @notification_text.setter
    def notification_text(self, notification_text):
        """
        Sets the notification_text of this NotificationSummary.
        Notification text


        :param notification_text: The notification_text of this NotificationSummary.
        :type: str
        """
        self._notification_text = notification_text

    @property
    def id(self):
        """
        **[Required]** Gets the id of this NotificationSummary.
        Notification identifier.


        :return: The id of this NotificationSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NotificationSummary.
        Notification identifier.


        :param id: The id of this NotificationSummary.
        :type: str
        """
        self._id = id

    @property
    def time_published(self):
        """
        **[Required]** Gets the time_published of this NotificationSummary.
        Published date


        :return: The time_published of this NotificationSummary.
        :rtype: datetime
        """
        return self._time_published

    @time_published.setter
    def time_published(self, time_published):
        """
        Sets the time_published of this NotificationSummary.
        Published date


        :param time_published: The time_published of this NotificationSummary.
        :type: datetime
        """
        self._time_published = time_published

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricError(object):
    """
    Metric error content.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricError object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_generated:
            The value to assign to the time_generated property of this MetricError.
        :type time_generated: datetime

        :param error_type:
            The value to assign to the error_type property of this MetricError.
        :type error_type: str

        :param content_type:
            The value to assign to the content_type property of this MetricError.
        :type content_type: str

        :param data:
            The value to assign to the data property of this MetricError.
        :type data: str

        :param subject:
            The value to assign to the subject property of this MetricError.
        :type subject: str

        :param level:
            The value to assign to the level property of this MetricError.
        :type level: str

        """
        self.swagger_types = {
            'time_generated': 'datetime',
            'error_type': 'str',
            'content_type': 'str',
            'data': 'str',
            'subject': 'str',
            'level': 'str'
        }
        self.attribute_map = {
            'time_generated': 'timeGenerated',
            'error_type': 'errorType',
            'content_type': 'contentType',
            'data': 'data',
            'subject': 'subject',
            'level': 'level'
        }
        self._time_generated = None
        self._error_type = None
        self._content_type = None
        self._data = None
        self._subject = None
        self._level = None

    @property
    def time_generated(self):
        """
        **[Required]** Gets the time_generated of this MetricError.
        Time the error record was generated


        :return: The time_generated of this MetricError.
        :rtype: datetime
        """
        return self._time_generated

    @time_generated.setter
    def time_generated(self, time_generated):
        """
        Sets the time_generated of this MetricError.
        Time the error record was generated


        :param time_generated: The time_generated of this MetricError.
        :type: datetime
        """
        self._time_generated = time_generated

    @property
    def error_type(self):
        """
        **[Required]** Gets the error_type of this MetricError.
        Error type


        :return: The error_type of this MetricError.
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """
        Sets the error_type of this MetricError.
        Error type


        :param error_type: The error_type of this MetricError.
        :type: str
        """
        self._error_type = error_type

    @property
    def content_type(self):
        """
        **[Required]** Gets the content_type of this MetricError.
        Content type


        :return: The content_type of this MetricError.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this MetricError.
        Content type


        :param content_type: The content_type of this MetricError.
        :type: str
        """
        self._content_type = content_type

    @property
    def data(self):
        """
        **[Required]** Gets the data of this MetricError.
        Data


        :return: The data of this MetricError.
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this MetricError.
        Data


        :param data: The data of this MetricError.
        :type: str
        """
        self._data = data

    @property
    def subject(self):
        """
        **[Required]** Gets the subject of this MetricError.
        Subject


        :return: The subject of this MetricError.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this MetricError.
        Subject


        :param subject: The subject of this MetricError.
        :type: str
        """
        self._subject = subject

    @property
    def level(self):
        """
        **[Required]** Gets the level of this MetricError.
        Level


        :return: The level of this MetricError.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this MetricError.
        Level


        :param level: The level of this MetricError.
        :type: str
        """
        self._level = level

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchActivityDetails(object):
    """
    Details of deploy, update and migrate-listener(only for single Instance database) operations for this resource.
    """

    #: A constant which can be used with the deploy_status property of a PatchActivityDetails.
    #: This constant has a value of "SCHEDULED"
    DEPLOY_STATUS_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the deploy_status property of a PatchActivityDetails.
    #: This constant has a value of "RUNNING"
    DEPLOY_STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the deploy_status property of a PatchActivityDetails.
    #: This constant has a value of "COMPLETED"
    DEPLOY_STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the deploy_status property of a PatchActivityDetails.
    #: This constant has a value of "FAILED"
    DEPLOY_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the update_status property of a PatchActivityDetails.
    #: This constant has a value of "SCHEDULED"
    UPDATE_STATUS_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the update_status property of a PatchActivityDetails.
    #: This constant has a value of "RUNNING"
    UPDATE_STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the update_status property of a PatchActivityDetails.
    #: This constant has a value of "COMPLETED"
    UPDATE_STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the update_status property of a PatchActivityDetails.
    #: This constant has a value of "FAILED"
    UPDATE_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the migrate_listener_status property of a PatchActivityDetails.
    #: This constant has a value of "SCHEDULED"
    MIGRATE_LISTENER_STATUS_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the migrate_listener_status property of a PatchActivityDetails.
    #: This constant has a value of "RUNNING"
    MIGRATE_LISTENER_STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the migrate_listener_status property of a PatchActivityDetails.
    #: This constant has a value of "COMPLETED"
    MIGRATE_LISTENER_STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the migrate_listener_status property of a PatchActivityDetails.
    #: This constant has a value of "FAILED"
    MIGRATE_LISTENER_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the migrate_listener_status property of a PatchActivityDetails.
    #: This constant has a value of "NA"
    MIGRATE_LISTENER_STATUS_NA = "NA"

    def __init__(self, **kwargs):
        """
        Initializes a new PatchActivityDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_operation_id:
            The value to assign to the deploy_operation_id property of this PatchActivityDetails.
        :type deploy_operation_id: str

        :param deploy_task_id:
            The value to assign to the deploy_task_id property of this PatchActivityDetails.
        :type deploy_task_id: str

        :param deploy_status:
            The value to assign to the deploy_status property of this PatchActivityDetails.
            Allowed values for this property are: "SCHEDULED", "RUNNING", "COMPLETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type deploy_status: str

        :param update_operation_id:
            The value to assign to the update_operation_id property of this PatchActivityDetails.
        :type update_operation_id: str

        :param update_task_id:
            The value to assign to the update_task_id property of this PatchActivityDetails.
        :type update_task_id: str

        :param update_status:
            The value to assign to the update_status property of this PatchActivityDetails.
            Allowed values for this property are: "SCHEDULED", "RUNNING", "COMPLETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type update_status: str

        :param migrate_listener_operation_id:
            The value to assign to the migrate_listener_operation_id property of this PatchActivityDetails.
        :type migrate_listener_operation_id: str

        :param migrate_listener_task_id:
            The value to assign to the migrate_listener_task_id property of this PatchActivityDetails.
        :type migrate_listener_task_id: str

        :param migrate_listener_status:
            The value to assign to the migrate_listener_status property of this PatchActivityDetails.
            Allowed values for this property are: "SCHEDULED", "RUNNING", "COMPLETED", "FAILED", "NA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type migrate_listener_status: str

        """
        self.swagger_types = {
            'deploy_operation_id': 'str',
            'deploy_task_id': 'str',
            'deploy_status': 'str',
            'update_operation_id': 'str',
            'update_task_id': 'str',
            'update_status': 'str',
            'migrate_listener_operation_id': 'str',
            'migrate_listener_task_id': 'str',
            'migrate_listener_status': 'str'
        }
        self.attribute_map = {
            'deploy_operation_id': 'deployOperationId',
            'deploy_task_id': 'deployTaskId',
            'deploy_status': 'deployStatus',
            'update_operation_id': 'updateOperationId',
            'update_task_id': 'updateTaskId',
            'update_status': 'updateStatus',
            'migrate_listener_operation_id': 'migrateListenerOperationId',
            'migrate_listener_task_id': 'migrateListenerTaskId',
            'migrate_listener_status': 'migrateListenerStatus'
        }
        self._deploy_operation_id = None
        self._deploy_task_id = None
        self._deploy_status = None
        self._update_operation_id = None
        self._update_task_id = None
        self._update_status = None
        self._migrate_listener_operation_id = None
        self._migrate_listener_task_id = None
        self._migrate_listener_status = None

    @property
    def deploy_operation_id(self):
        """
        Gets the deploy_operation_id of this PatchActivityDetails.
        Operation Identifier for deploy operation.


        :return: The deploy_operation_id of this PatchActivityDetails.
        :rtype: str
        """
        return self._deploy_operation_id

    @deploy_operation_id.setter
    def deploy_operation_id(self, deploy_operation_id):
        """
        Sets the deploy_operation_id of this PatchActivityDetails.
        Operation Identifier for deploy operation.


        :param deploy_operation_id: The deploy_operation_id of this PatchActivityDetails.
        :type: str
        """
        self._deploy_operation_id = deploy_operation_id

    @property
    def deploy_task_id(self):
        """
        Gets the deploy_task_id of this PatchActivityDetails.
        Task identifier for deploy operation.


        :return: The deploy_task_id of this PatchActivityDetails.
        :rtype: str
        """
        return self._deploy_task_id

    @deploy_task_id.setter
    def deploy_task_id(self, deploy_task_id):
        """
        Sets the deploy_task_id of this PatchActivityDetails.
        Task identifier for deploy operation.


        :param deploy_task_id: The deploy_task_id of this PatchActivityDetails.
        :type: str
        """
        self._deploy_task_id = deploy_task_id

    @property
    def deploy_status(self):
        """
        Gets the deploy_status of this PatchActivityDetails.
        Status of deploy operation.

        Allowed values for this property are: "SCHEDULED", "RUNNING", "COMPLETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The deploy_status of this PatchActivityDetails.
        :rtype: str
        """
        return self._deploy_status

    @deploy_status.setter
    def deploy_status(self, deploy_status):
        """
        Sets the deploy_status of this PatchActivityDetails.
        Status of deploy operation.


        :param deploy_status: The deploy_status of this PatchActivityDetails.
        :type: str
        """
        allowed_values = ["SCHEDULED", "RUNNING", "COMPLETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(deploy_status, allowed_values):
            deploy_status = 'UNKNOWN_ENUM_VALUE'
        self._deploy_status = deploy_status

    @property
    def update_operation_id(self):
        """
        Gets the update_operation_id of this PatchActivityDetails.
        Operation Identifier for update operation.


        :return: The update_operation_id of this PatchActivityDetails.
        :rtype: str
        """
        return self._update_operation_id

    @update_operation_id.setter
    def update_operation_id(self, update_operation_id):
        """
        Sets the update_operation_id of this PatchActivityDetails.
        Operation Identifier for update operation.


        :param update_operation_id: The update_operation_id of this PatchActivityDetails.
        :type: str
        """
        self._update_operation_id = update_operation_id

    @property
    def update_task_id(self):
        """
        Gets the update_task_id of this PatchActivityDetails.
        Task identifier for update operation.


        :return: The update_task_id of this PatchActivityDetails.
        :rtype: str
        """
        return self._update_task_id

    @update_task_id.setter
    def update_task_id(self, update_task_id):
        """
        Sets the update_task_id of this PatchActivityDetails.
        Task identifier for update operation.


        :param update_task_id: The update_task_id of this PatchActivityDetails.
        :type: str
        """
        self._update_task_id = update_task_id

    @property
    def update_status(self):
        """
        Gets the update_status of this PatchActivityDetails.
        Status of update operation.

        Allowed values for this property are: "SCHEDULED", "RUNNING", "COMPLETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The update_status of this PatchActivityDetails.
        :rtype: str
        """
        return self._update_status

    @update_status.setter
    def update_status(self, update_status):
        """
        Sets the update_status of this PatchActivityDetails.
        Status of update operation.


        :param update_status: The update_status of this PatchActivityDetails.
        :type: str
        """
        allowed_values = ["SCHEDULED", "RUNNING", "COMPLETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(update_status, allowed_values):
            update_status = 'UNKNOWN_ENUM_VALUE'
        self._update_status = update_status

    @property
    def migrate_listener_operation_id(self):
        """
        Gets the migrate_listener_operation_id of this PatchActivityDetails.
        Operation Identifier for migrate listener operation.


        :return: The migrate_listener_operation_id of this PatchActivityDetails.
        :rtype: str
        """
        return self._migrate_listener_operation_id

    @migrate_listener_operation_id.setter
    def migrate_listener_operation_id(self, migrate_listener_operation_id):
        """
        Sets the migrate_listener_operation_id of this PatchActivityDetails.
        Operation Identifier for migrate listener operation.


        :param migrate_listener_operation_id: The migrate_listener_operation_id of this PatchActivityDetails.
        :type: str
        """
        self._migrate_listener_operation_id = migrate_listener_operation_id

    @property
    def migrate_listener_task_id(self):
        """
        Gets the migrate_listener_task_id of this PatchActivityDetails.
        Task identifier for migrate listener operation.


        :return: The migrate_listener_task_id of this PatchActivityDetails.
        :rtype: str
        """
        return self._migrate_listener_task_id

    @migrate_listener_task_id.setter
    def migrate_listener_task_id(self, migrate_listener_task_id):
        """
        Sets the migrate_listener_task_id of this PatchActivityDetails.
        Task identifier for migrate listener operation.


        :param migrate_listener_task_id: The migrate_listener_task_id of this PatchActivityDetails.
        :type: str
        """
        self._migrate_listener_task_id = migrate_listener_task_id

    @property
    def migrate_listener_status(self):
        """
        Gets the migrate_listener_status of this PatchActivityDetails.
        Status of migrate listener operation.

        Allowed values for this property are: "SCHEDULED", "RUNNING", "COMPLETED", "FAILED", "NA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The migrate_listener_status of this PatchActivityDetails.
        :rtype: str
        """
        return self._migrate_listener_status

    @migrate_listener_status.setter
    def migrate_listener_status(self, migrate_listener_status):
        """
        Sets the migrate_listener_status of this PatchActivityDetails.
        Status of migrate listener operation.


        :param migrate_listener_status: The migrate_listener_status of this PatchActivityDetails.
        :type: str
        """
        allowed_values = ["SCHEDULED", "RUNNING", "COMPLETED", "FAILED", "NA"]
        if not value_allowed_none_or_none_sentinel(migrate_listener_status, allowed_values):
            migrate_listener_status = 'UNKNOWN_ENUM_VALUE'
        self._migrate_listener_status = migrate_listener_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilitySummary(object):
    """
    The vulnerability summary.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilitySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cve_id:
            The value to assign to the cve_id property of this VulnerabilitySummary.
        :type cve_id: str

        :param description:
            The value to assign to the description property of this VulnerabilitySummary.
        :type description: str

        :param risk_level:
            The value to assign to the risk_level property of this VulnerabilitySummary.
        :type risk_level: str

        :param score:
            The value to assign to the score property of this VulnerabilitySummary.
        :type score: str

        :param vulnerable_resources_count:
            The value to assign to the vulnerable_resources_count property of this VulnerabilitySummary.
        :type vulnerable_resources_count: int

        """
        self.swagger_types = {
            'cve_id': 'str',
            'description': 'str',
            'risk_level': 'str',
            'score': 'str',
            'vulnerable_resources_count': 'int'
        }
        self.attribute_map = {
            'cve_id': 'cveId',
            'description': 'description',
            'risk_level': 'riskLevel',
            'score': 'score',
            'vulnerable_resources_count': 'vulnerableResourcesCount'
        }
        self._cve_id = None
        self._description = None
        self._risk_level = None
        self._score = None
        self._vulnerable_resources_count = None

    @property
    def cve_id(self):
        """
        **[Required]** Gets the cve_id of this VulnerabilitySummary.
        CVE vulnerability ID


        :return: The cve_id of this VulnerabilitySummary.
        :rtype: str
        """
        return self._cve_id

    @cve_id.setter
    def cve_id(self, cve_id):
        """
        Sets the cve_id of this VulnerabilitySummary.
        CVE vulnerability ID


        :param cve_id: The cve_id of this VulnerabilitySummary.
        :type: str
        """
        self._cve_id = cve_id

    @property
    def description(self):
        """
        **[Required]** Gets the description of this VulnerabilitySummary.
        Vulnerability description


        :return: The description of this VulnerabilitySummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this VulnerabilitySummary.
        Vulnerability description


        :param description: The description of this VulnerabilitySummary.
        :type: str
        """
        self._description = description

    @property
    def risk_level(self):
        """
        **[Required]** Gets the risk_level of this VulnerabilitySummary.
        Risk level enumeration


        :return: The risk_level of this VulnerabilitySummary.
        :rtype: str
        """
        return self._risk_level

    @risk_level.setter
    def risk_level(self, risk_level):
        """
        Sets the risk_level of this VulnerabilitySummary.
        Risk level enumeration


        :param risk_level: The risk_level of this VulnerabilitySummary.
        :type: str
        """
        self._risk_level = risk_level

    @property
    def score(self):
        """
        **[Required]** Gets the score of this VulnerabilitySummary.
        Vulnerability score


        :return: The score of this VulnerabilitySummary.
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Sets the score of this VulnerabilitySummary.
        Vulnerability score


        :param score: The score of this VulnerabilitySummary.
        :type: str
        """
        self._score = score

    @property
    def vulnerable_resources_count(self):
        """
        **[Required]** Gets the vulnerable_resources_count of this VulnerabilitySummary.
        Number of vulnerable resources


        :return: The vulnerable_resources_count of this VulnerabilitySummary.
        :rtype: int
        """
        return self._vulnerable_resources_count

    @vulnerable_resources_count.setter
    def vulnerable_resources_count(self, vulnerable_resources_count):
        """
        Sets the vulnerable_resources_count of this VulnerabilitySummary.
        Number of vulnerable resources


        :param vulnerable_resources_count: The vulnerable_resources_count of this VulnerabilitySummary.
        :type: int
        """
        self._vulnerable_resources_count = vulnerable_resources_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilityScanSummary(object):
    """
    Summary information about a VulnerabilityScan.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilityScanSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VulnerabilityScanSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this VulnerabilityScanSummary.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this VulnerabilityScanSummary.
        :type compartment_id: str

        :param vulnerability_scan_type:
            The value to assign to the vulnerability_scan_type property of this VulnerabilityScanSummary.
        :type vulnerability_scan_type: str

        :param vulnerability_scan_status:
            The value to assign to the vulnerability_scan_status property of this VulnerabilityScanSummary.
        :type vulnerability_scan_status: str

        :param vulnerability_scan_message:
            The value to assign to the vulnerability_scan_message property of this VulnerabilityScanSummary.
        :type vulnerability_scan_message: str

        :param time_created:
            The value to assign to the time_created property of this VulnerabilityScanSummary.
        :type time_created: datetime

        :param time_ended:
            The value to assign to the time_ended property of this VulnerabilityScanSummary.
        :type time_ended: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VulnerabilityScanSummary.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this VulnerabilityScanSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this VulnerabilityScanSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this VulnerabilityScanSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'vulnerability_scan_type': 'str',
            'vulnerability_scan_status': 'str',
            'vulnerability_scan_message': 'str',
            'time_created': 'datetime',
            'time_ended': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'vulnerability_scan_type': 'vulnerabilityScanType',
            'vulnerability_scan_status': 'vulnerabilityScanStatus',
            'vulnerability_scan_message': 'vulnerabilityScanMessage',
            'time_created': 'timeCreated',
            'time_ended': 'timeEnded',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._vulnerability_scan_type = None
        self._vulnerability_scan_status = None
        self._vulnerability_scan_message = None
        self._time_created = None
        self._time_ended = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VulnerabilityScanSummary.
        The `OCID`__ of the VulnerabilityScan.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VulnerabilityScanSummary.
        The `OCID`__ of the VulnerabilityScan.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this VulnerabilityScanSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this VulnerabilityScanSummary.
        A user-friendly name. Does not have to be unique, and it's changeable.


        :return: The display_name of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this VulnerabilityScanSummary.
        A user-friendly name. Does not have to be unique, and it's changeable.


        :param display_name: The display_name of this VulnerabilityScanSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this VulnerabilityScanSummary.
        The `OCID`__ of the compartment.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VulnerabilityScanSummary.
        The `OCID`__ of the compartment.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this VulnerabilityScanSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def vulnerability_scan_type(self):
        """
        **[Required]** Gets the vulnerability_scan_type of this VulnerabilityScanSummary.
        Vulnerability Scan Type.


        :return: The vulnerability_scan_type of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._vulnerability_scan_type

    @vulnerability_scan_type.setter
    def vulnerability_scan_type(self, vulnerability_scan_type):
        """
        Sets the vulnerability_scan_type of this VulnerabilityScanSummary.
        Vulnerability Scan Type.


        :param vulnerability_scan_type: The vulnerability_scan_type of this VulnerabilityScanSummary.
        :type: str
        """
        self._vulnerability_scan_type = vulnerability_scan_type

    @property
    def vulnerability_scan_status(self):
        """
        **[Required]** Gets the vulnerability_scan_status of this VulnerabilityScanSummary.
        The status of the scan.


        :return: The vulnerability_scan_status of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._vulnerability_scan_status

    @vulnerability_scan_status.setter
    def vulnerability_scan_status(self, vulnerability_scan_status):
        """
        Sets the vulnerability_scan_status of this VulnerabilityScanSummary.
        The status of the scan.


        :param vulnerability_scan_status: The vulnerability_scan_status of this VulnerabilityScanSummary.
        :type: str
        """
        self._vulnerability_scan_status = vulnerability_scan_status

    @property
    def vulnerability_scan_message(self):
        """
        **[Required]** Gets the vulnerability_scan_message of this VulnerabilityScanSummary.
        The message of the scan status.


        :return: The vulnerability_scan_message of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._vulnerability_scan_message

    @vulnerability_scan_message.setter
    def vulnerability_scan_message(self, vulnerability_scan_message):
        """
        Sets the vulnerability_scan_message of this VulnerabilityScanSummary.
        The message of the scan status.


        :param vulnerability_scan_message: The vulnerability_scan_message of this VulnerabilityScanSummary.
        :type: str
        """
        self._vulnerability_scan_message = vulnerability_scan_message

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this VulnerabilityScanSummary.
        The date and time the VulnerabilityScan was created, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this VulnerabilityScanSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this VulnerabilityScanSummary.
        The date and time the VulnerabilityScan was created, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this VulnerabilityScanSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_ended(self):
        """
        **[Required]** Gets the time_ended of this VulnerabilityScanSummary.
        The date and time the VulnerabilityScan was updated, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_ended of this VulnerabilityScanSummary.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this VulnerabilityScanSummary.
        The date and time the VulnerabilityScan was updated, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_ended: The time_ended of this VulnerabilityScanSummary.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this VulnerabilityScanSummary.
        The current state of the PatchOperation.


        :return: The lifecycle_state of this VulnerabilityScanSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VulnerabilityScanSummary.
        The current state of the PatchOperation.


        :param lifecycle_state: The lifecycle_state of this VulnerabilityScanSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this VulnerabilityScanSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this VulnerabilityScanSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this VulnerabilityScanSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this VulnerabilityScanSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this VulnerabilityScanSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this VulnerabilityScanSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this VulnerabilityScanSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this VulnerabilityScanSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this VulnerabilityScanSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this VulnerabilityScanSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this VulnerabilityScanSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this VulnerabilityScanSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AggregatedVulnerabilitySummary(object):
    """
    Singular information of an aggregated vulnerability datapoint.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AggregatedVulnerabilitySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param timestamp:
            The value to assign to the timestamp property of this AggregatedVulnerabilitySummary.
        :type timestamp: datetime

        :param vulnerabilities_count:
            The value to assign to the vulnerabilities_count property of this AggregatedVulnerabilitySummary.
        :type vulnerabilities_count: int

        :param registered_resources_count:
            The value to assign to the registered_resources_count property of this AggregatedVulnerabilitySummary.
        :type registered_resources_count: int

        """
        self.swagger_types = {
            'timestamp': 'datetime',
            'vulnerabilities_count': 'int',
            'registered_resources_count': 'int'
        }
        self.attribute_map = {
            'timestamp': 'timestamp',
            'vulnerabilities_count': 'vulnerabilitiesCount',
            'registered_resources_count': 'registeredResourcesCount'
        }
        self._timestamp = None
        self._vulnerabilities_count = None
        self._registered_resources_count = None

    @property
    def timestamp(self):
        """
        **[Required]** Gets the timestamp of this AggregatedVulnerabilitySummary.
        UTC timestamp when the scan completed.


        :return: The timestamp of this AggregatedVulnerabilitySummary.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this AggregatedVulnerabilitySummary.
        UTC timestamp when the scan completed.


        :param timestamp: The timestamp of this AggregatedVulnerabilitySummary.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def vulnerabilities_count(self):
        """
        **[Required]** Gets the vulnerabilities_count of this AggregatedVulnerabilitySummary.
        Unresolved vulnerabilities that were found by the scan.


        :return: The vulnerabilities_count of this AggregatedVulnerabilitySummary.
        :rtype: int
        """
        return self._vulnerabilities_count

    @vulnerabilities_count.setter
    def vulnerabilities_count(self, vulnerabilities_count):
        """
        Sets the vulnerabilities_count of this AggregatedVulnerabilitySummary.
        Unresolved vulnerabilities that were found by the scan.


        :param vulnerabilities_count: The vulnerabilities_count of this AggregatedVulnerabilitySummary.
        :type: int
        """
        self._vulnerabilities_count = vulnerabilities_count

    @property
    def registered_resources_count(self):
        """
        **[Required]** Gets the registered_resources_count of this AggregatedVulnerabilitySummary.
        Registered databases against which the scan ran.


        :return: The registered_resources_count of this AggregatedVulnerabilitySummary.
        :rtype: int
        """
        return self._registered_resources_count

    @registered_resources_count.setter
    def registered_resources_count(self, registered_resources_count):
        """
        Sets the registered_resources_count of this AggregatedVulnerabilitySummary.
        Registered databases against which the scan ran.


        :param registered_resources_count: The registered_resources_count of this AggregatedVulnerabilitySummary.
        :type: int
        """
        self._registered_resources_count = registered_resources_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DblmPatchManagement(object):
    """
    Description of PatchManagement.
    """

    #: A constant which can be used with the lifecycle_state property of a DblmPatchManagement.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DblmPatchManagement.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DblmPatchManagement.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a DblmPatchManagement.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    def __init__(self, **kwargs):
        """
        Initializes a new DblmPatchManagement object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this DblmPatchManagement.
        :type compartment_id: str

        :param resources:
            The value to assign to the resources property of this DblmPatchManagement.
        :type resources: list[oci.dblm.models.ResourceInfo]

        :param message:
            The value to assign to the message property of this DblmPatchManagement.
        :type message: str

        :param time_enabled:
            The value to assign to the time_enabled property of this DblmPatchManagement.
        :type time_enabled: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DblmPatchManagement.
            Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param patch_operations_summary:
            The value to assign to the patch_operations_summary property of this DblmPatchManagement.
        :type patch_operations_summary: object

        :param images_patch_recommendation_summary:
            The value to assign to the images_patch_recommendation_summary property of this DblmPatchManagement.
        :type images_patch_recommendation_summary: object

        :param resources_patch_compliance_summary:
            The value to assign to the resources_patch_compliance_summary property of this DblmPatchManagement.
        :type resources_patch_compliance_summary: object

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DblmPatchManagement.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DblmPatchManagement.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DblmPatchManagement.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'resources': 'list[ResourceInfo]',
            'message': 'str',
            'time_enabled': 'datetime',
            'lifecycle_state': 'str',
            'patch_operations_summary': 'object',
            'images_patch_recommendation_summary': 'object',
            'resources_patch_compliance_summary': 'object',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'resources': 'resources',
            'message': 'message',
            'time_enabled': 'timeEnabled',
            'lifecycle_state': 'lifecycleState',
            'patch_operations_summary': 'patchOperationsSummary',
            'images_patch_recommendation_summary': 'imagesPatchRecommendationSummary',
            'resources_patch_compliance_summary': 'resourcesPatchComplianceSummary',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._compartment_id = None
        self._resources = None
        self._message = None
        self._time_enabled = None
        self._lifecycle_state = None
        self._patch_operations_summary = None
        self._images_patch_recommendation_summary = None
        self._resources_patch_compliance_summary = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DblmPatchManagement.
        Compartment Identifier


        :return: The compartment_id of this DblmPatchManagement.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DblmPatchManagement.
        Compartment Identifier


        :param compartment_id: The compartment_id of this DblmPatchManagement.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def resources(self):
        """
        Gets the resources of this DblmPatchManagement.
        resources objects


        :return: The resources of this DblmPatchManagement.
        :rtype: list[oci.dblm.models.ResourceInfo]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """
        Sets the resources of this DblmPatchManagement.
        resources objects


        :param resources: The resources of this DblmPatchManagement.
        :type: list[oci.dblm.models.ResourceInfo]
        """
        self._resources = resources

    @property
    def message(self):
        """
        Gets the message of this DblmPatchManagement.
        A message describing the status of the feature's state


        :return: The message of this DblmPatchManagement.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this DblmPatchManagement.
        A message describing the status of the feature's state


        :param message: The message of this DblmPatchManagement.
        :type: str
        """
        self._message = message

    @property
    def time_enabled(self):
        """
        Gets the time_enabled of this DblmPatchManagement.
        The time the Vulnerability was enabled. An RFC3339 formatted datetime string.


        :return: The time_enabled of this DblmPatchManagement.
        :rtype: datetime
        """
        return self._time_enabled

    @time_enabled.setter
    def time_enabled(self, time_enabled):
        """
        Sets the time_enabled of this DblmPatchManagement.
        The time the Vulnerability was enabled. An RFC3339 formatted datetime string.


        :param time_enabled: The time_enabled of this DblmPatchManagement.
        :type: datetime
        """
        self._time_enabled = time_enabled

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DblmPatchManagement.
        The current state of the feature.

        Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DblmPatchManagement.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DblmPatchManagement.
        The current state of the feature.


        :param lifecycle_state: The lifecycle_state of this DblmPatchManagement.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "FAILED", "NEEDS_ATTENTION"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def patch_operations_summary(self):
        """
        Gets the patch_operations_summary of this DblmPatchManagement.
        Summary of patch operations.


        :return: The patch_operations_summary of this DblmPatchManagement.
        :rtype: object
        """
        return self._patch_operations_summary

    @patch_operations_summary.setter
    def patch_operations_summary(self, patch_operations_summary):
        """
        Sets the patch_operations_summary of this DblmPatchManagement.
        Summary of patch operations.


        :param patch_operations_summary: The patch_operations_summary of this DblmPatchManagement.
        :type: object
        """
        self._patch_operations_summary = patch_operations_summary

    @property
    def images_patch_recommendation_summary(self):
        """
        Gets the images_patch_recommendation_summary of this DblmPatchManagement.
        Summary of image patches recommended to install.


        :return: The images_patch_recommendation_summary of this DblmPatchManagement.
        :rtype: object
        """
        return self._images_patch_recommendation_summary

    @images_patch_recommendation_summary.setter
    def images_patch_recommendation_summary(self, images_patch_recommendation_summary):
        """
        Sets the images_patch_recommendation_summary of this DblmPatchManagement.
        Summary of image patches recommended to install.


        :param images_patch_recommendation_summary: The images_patch_recommendation_summary of this DblmPatchManagement.
        :type: object
        """
        self._images_patch_recommendation_summary = images_patch_recommendation_summary

    @property
    def resources_patch_compliance_summary(self):
        """
        Gets the resources_patch_compliance_summary of this DblmPatchManagement.
        Summary of image patches to be compliant to install.


        :return: The resources_patch_compliance_summary of this DblmPatchManagement.
        :rtype: object
        """
        return self._resources_patch_compliance_summary

    @resources_patch_compliance_summary.setter
    def resources_patch_compliance_summary(self, resources_patch_compliance_summary):
        """
        Sets the resources_patch_compliance_summary of this DblmPatchManagement.
        Summary of image patches to be compliant to install.


        :param resources_patch_compliance_summary: The resources_patch_compliance_summary of this DblmPatchManagement.
        :type: object
        """
        self._resources_patch_compliance_summary = resources_patch_compliance_summary

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DblmPatchManagement.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DblmPatchManagement.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DblmPatchManagement.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DblmPatchManagement.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DblmPatchManagement.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DblmPatchManagement.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DblmPatchManagement.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DblmPatchManagement.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DblmPatchManagement.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DblmPatchManagement.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DblmPatchManagement.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DblmPatchManagement.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DblmVulnerability(object):
    """
    A Dblm Vulnerability is a description of a Dblm Vulnerability.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to
    an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.oracle.com/iaas/Content/Identity/policiesgs/get-started-with-policies.htm
    """

    #: A constant which can be used with the lifecycle_state property of a DblmVulnerability.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DblmVulnerability.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DblmVulnerability.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a DblmVulnerability.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    #: A constant which can be used with the lifecycle_state property of a DblmVulnerability.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DblmVulnerability.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new DblmVulnerability object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this DblmVulnerability.
        :type compartment_id: str

        :param resources:
            The value to assign to the resources property of this DblmVulnerability.
        :type resources: list[oci.dblm.models.ResourceInfo]

        :param message:
            The value to assign to the message property of this DblmVulnerability.
        :type message: str

        :param time_enabled:
            The value to assign to the time_enabled property of this DblmVulnerability.
        :type time_enabled: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DblmVulnerability.
            Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "NEEDS_ATTENTION", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param resources_summary:
            The value to assign to the resources_summary property of this DblmVulnerability.
        :type resources_summary: object

        :param vulnerabilities_summary:
            The value to assign to the vulnerabilities_summary property of this DblmVulnerability.
        :type vulnerabilities_summary: object

        :param patch_recommendations_summary:
            The value to assign to the patch_recommendations_summary property of this DblmVulnerability.
        :type patch_recommendations_summary: object

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DblmVulnerability.
        :type freeform_tags: dict(str, str)

        :param system_tags:
            The value to assign to the system_tags property of this DblmVulnerability.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'resources': 'list[ResourceInfo]',
            'message': 'str',
            'time_enabled': 'datetime',
            'lifecycle_state': 'str',
            'resources_summary': 'object',
            'vulnerabilities_summary': 'object',
            'patch_recommendations_summary': 'object',
            'freeform_tags': 'dict(str, str)',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'resources': 'resources',
            'message': 'message',
            'time_enabled': 'timeEnabled',
            'lifecycle_state': 'lifecycleState',
            'resources_summary': 'resourcesSummary',
            'vulnerabilities_summary': 'vulnerabilitiesSummary',
            'patch_recommendations_summary': 'patchRecommendationsSummary',
            'freeform_tags': 'freeformTags',
            'system_tags': 'systemTags'
        }
        self._compartment_id = None
        self._resources = None
        self._message = None
        self._time_enabled = None
        self._lifecycle_state = None
        self._resources_summary = None
        self._vulnerabilities_summary = None
        self._patch_recommendations_summary = None
        self._freeform_tags = None
        self._system_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DblmVulnerability.
        Compartment Identifier.


        :return: The compartment_id of this DblmVulnerability.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DblmVulnerability.
        Compartment Identifier.


        :param compartment_id: The compartment_id of this DblmVulnerability.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def resources(self):
        """
        Gets the resources of this DblmVulnerability.
        Resources objects.


        :return: The resources of this DblmVulnerability.
        :rtype: list[oci.dblm.models.ResourceInfo]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """
        Sets the resources of this DblmVulnerability.
        Resources objects.


        :param resources: The resources of this DblmVulnerability.
        :type: list[oci.dblm.models.ResourceInfo]
        """
        self._resources = resources

    @property
    def message(self):
        """
        Gets the message of this DblmVulnerability.
        A message describing the status of the feature's state.


        :return: The message of this DblmVulnerability.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this DblmVulnerability.
        A message describing the status of the feature's state.


        :param message: The message of this DblmVulnerability.
        :type: str
        """
        self._message = message

    @property
    def time_enabled(self):
        """
        Gets the time_enabled of this DblmVulnerability.
        The time the the Vulnerability was enabled. An RFC3339 formatted datetime string.


        :return: The time_enabled of this DblmVulnerability.
        :rtype: datetime
        """
        return self._time_enabled

    @time_enabled.setter
    def time_enabled(self, time_enabled):
        """
        Sets the time_enabled of this DblmVulnerability.
        The time the the Vulnerability was enabled. An RFC3339 formatted datetime string.


        :param time_enabled: The time_enabled of this DblmVulnerability.
        :type: datetime
        """
        self._time_enabled = time_enabled

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DblmVulnerability.
        The current state of the feature.

        Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "NEEDS_ATTENTION", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DblmVulnerability.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DblmVulnerability.
        The current state of the feature.


        :param lifecycle_state: The lifecycle_state of this DblmVulnerability.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "FAILED", "NEEDS_ATTENTION", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def resources_summary(self):
        """
        Gets the resources_summary of this DblmVulnerability.
        Summary of dblm registered and unregistered resources.


        :return: The resources_summary of this DblmVulnerability.
        :rtype: object
        """
        return self._resources_summary

    @resources_summary.setter
    def resources_summary(self, resources_summary):
        """
        Sets the resources_summary of this DblmVulnerability.
        Summary of dblm registered and unregistered resources.


        :param resources_summary: The resources_summary of this DblmVulnerability.
        :type: object
        """
        self._resources_summary = resources_summary

    @property
    def vulnerabilities_summary(self):
        """
        Gets the vulnerabilities_summary of this DblmVulnerability.
        Summary of vulnerabilities found in registered resources grouped by severity.


        :return: The vulnerabilities_summary of this DblmVulnerability.
        :rtype: object
        """
        return self._vulnerabilities_summary

    @vulnerabilities_summary.setter
    def vulnerabilities_summary(self, vulnerabilities_summary):
        """
        Sets the vulnerabilities_summary of this DblmVulnerability.
        Summary of vulnerabilities found in registered resources grouped by severity.


        :param vulnerabilities_summary: The vulnerabilities_summary of this DblmVulnerability.
        :type: object
        """
        self._vulnerabilities_summary = vulnerabilities_summary

    @property
    def patch_recommendations_summary(self):
        """
        Gets the patch_recommendations_summary of this DblmVulnerability.
        Summary of the patch recommendations for databases.


        :return: The patch_recommendations_summary of this DblmVulnerability.
        :rtype: object
        """
        return self._patch_recommendations_summary

    @patch_recommendations_summary.setter
    def patch_recommendations_summary(self, patch_recommendations_summary):
        """
        Sets the patch_recommendations_summary of this DblmVulnerability.
        Summary of the patch recommendations for databases.


        :param patch_recommendations_summary: The patch_recommendations_summary of this DblmVulnerability.
        :type: object
        """
        self._patch_recommendations_summary = patch_recommendations_summary

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DblmVulnerability.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DblmVulnerability.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DblmVulnerability.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DblmVulnerability.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DblmVulnerability.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DblmVulnerability.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DblmVulnerability.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DblmVulnerability.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
